# The Geniverse API
Open source library to access and utilize generative AI models. 

Current models:
- VQGAN
- Aphantasia
- Mini-Dalle

For now you can generate images from text prompts, interpolate and create infinite zooms with your results. 
